"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const Listr = require("listr");
const base_1 = require("../../base");
const github_1 = require("../../github");
class SetDefaultBranch extends base_1.default {
    constructor() {
        super(...arguments);
        this.modifyRepos = async (repos) => {
            const userConfig = await this.getConfig();
            const { force, concurrency, } = this.flags;
            const listrOpts = {
                renderer: (this.flags.verbose ? 'verbose' : 'default'),
                concurrent: concurrency,
                exitOnError: !force,
            };
            const tasks = repos.map(repo => {
                return {
                    title: `Modify "${repo.name}"`,
                    task: (_ctx, task) => {
                        const modifyRepoParams = {
                            owner: repo.owner,
                            name: repo.name,
                            repo: repo.repo,
                            default_branch: 'develop',
                            authToken: userConfig.authToken,
                        };
                        return this.modifyRepo(modifyRepoParams, task);
                    }
                };
            });
            const listr = new Listr(tasks, listrOpts);
            return listr.run()
                .catch((err) => {
                console.error(err);
            });
        };
        this.modifyRepo = async (params, _task) => {
            return github_1.editRepo(params);
        };
    }
    async run() {
        const userConfig = await this.requireConfig();
        this.log('Getting repos...');
        const repos = await github_1.getRepos({
            authToken: userConfig.authToken,
            repoQuery: this.flags['github-query'],
            filter: this.flags.filter,
        })
            .catch(err => {
            console.log(err);
            process.exit(1);
        });
        if (repos) {
            return this.modifyRepos(repos);
        }
    }
}
SetDefaultBranch.description = 'Sets the default branch for all repos';
SetDefaultBranch.hidden = true;
SetDefaultBranch.args = [
    {
        name: 'defaultBranch',
        description: 'The branch to set as default',
        default: 'develop',
        required: false,
    },
];
SetDefaultBranch.examples = [
    '$ rtolms admin:set-default-branch',
    '$ rtolms admin:set-default-branch develop',
];
SetDefaultBranch.flags = Object.assign({}, base_1.default.flags, { filter: command_1.flags.string({
        description: 'RegExp to filter names of repos',
        default: '^lms-(core|custom)',
        hidden: true,
        required: true,
    }), 'github-query': command_1.flags.string({
        description: 'query passed to the github search API to find list of repos to clone',
        default: 'org:RoundtableLearning lms in:name archived:false',
        hidden: true,
        required: true,
    }) });
exports.default = SetDefaultBranch;
