"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const execa = require("execa");
const globby = require("globby");
const inquirer = require("inquirer");
const Listr = require("listr");
const base_1 = require("../base");
const flags_1 = require("../flags");
const utils_1 = require("../utils"); //tslint:disable-line no-unused no-unused-variable
const config_1 = require("./config");
class Git extends base_1.default {
    async run() {
        if (!this.configExists()) {
            console.error('Config not found. Run init to create a config.');
            await inquirer.prompt([
                {
                    type: 'confirm',
                    message: 'Do you want to run configuration now?',
                    name: 'runconfig',
                },
            ])
                .then(({ runconfig }) => {
                if (runconfig) {
                    return config_1.default.run([]);
                }
                this.log('KBAI.');
                this.exit(-1);
            });
        }
        const userConfig = await this.getConfig();
        const repos = await globby(userConfig.reposDir + '/*/', { onlyDirectories: true });
        const { force, concurrency, verbose, } = this.flags;
        const argv = this.argv;
        const listrOpts = {
            renderer: (() => {
                if (!process.stdout.isTTY)
                    return 'verbose';
                return verbose ? 'verbose' : 'default';
            })(),
            concurrent: concurrency,
            exitOnError: !force,
        };
        const listr = new Listr(repos.map(repoPath => {
            return {
                title: utils_1.decorateRepoPath(repoPath),
                task: (_ctx, task) => {
                    return execa('git', argv, { cwd: repoPath })
                        .then(({ stdout }) => {
                        task.output = stdout;
                    });
                },
            };
        }), listrOpts);
        return listr.run();
    }
}
Git.strict = false;
Git.description = 'Run any git operation on all customer repos';
Git.examples = [
    '$ rtolms git fetch',
];
Git.flags = Object.assign({}, base_1.default.flags, { verbose: command_1.flags.boolean({ char: 'v', description: 'Verbose' }), force: command_1.flags.boolean({ description: 'Do not stop on errors' }), concurrency: flags_1.concurrency({
        char: 'c',
        default: 1,
        required: true,
    }) });
exports.default = Git;
