"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const execa = require("execa");
const globby = require("globby");
const Listr = require("listr");
const path = require("path");
const base_1 = require("../base");
const flags_1 = require("../flags");
const status_renderer_1 = require("../status-renderer");
const utils_1 = require("../utils"); //tslint:disable-line no-unused no-unused-variable
class Status extends base_1.default {
    constructor() {
        super(...arguments);
        this.getRepoStatus = async (repoPath) => {
            return execa('git', ['status', '--branch', '--porcelain=v1', '-z'], { cwd: repoPath })
                .then(({ stdout }) => {
                return stdout;
            });
        };
    }
    async run() {
        const userConfig = await this.requireConfig();
        const repos = await globby(userConfig.reposDir + '/*/', { onlyDirectories: true });
        const { force, concurrency, verbose, fetch, } = this.flags;
        const listrOpts = {
            renderer: (() => {
                if (!process.stdout.isTTY)
                    return 'verbose';
                return verbose ? 'verbose' : status_renderer_1.default;
            })(),
            concurrent: concurrency,
            exitOnError: !force,
            showSubtasks: false,
            padTitleLength: (() => {
                return repos.reduce((acc, repoPath) => {
                    return Math.max(acc, path.basename(repoPath).length);
                }, 0) + 1;
            })(),
        };
        const listr = new Listr(repos.map(repoPath => {
            return {
                title: utils_1.decorateRepoPath(repoPath, { reset: false, basenameOnly: true }),
                task: (_ctx, task) => {
                    return new Listr([
                        {
                            title: 'Fetch remote',
                            skip: () => !fetch,
                            task: (_ctx, subtask) => {
                                return execa('git', ['fetch'], { cwd: repoPath })
                                    .then(({ stdout }) => {
                                    subtask.output = stdout;
                                });
                            }
                        },
                        {
                            title: 'Get status',
                            task: async (_ctx, _subtask) => {
                                const gitStatus = await this.getRepoStatus(repoPath);
                                task.output = `git status:${gitStatus}`;
                            },
                        }
                    ], listrOpts);
                },
            };
        }), listrOpts);
        return listr.run();
    }
}
Status.description = 'Shows status of all repos';
Status.aliases = ['st', 'stat'];
Status.flags = Object.assign({}, base_1.default.flags, { verbose: command_1.flags.boolean({ char: 'v', description: 'Verbose' }), force: command_1.flags.boolean({ description: 'Do not stop on errors' }), concurrency: flags_1.concurrency({
        char: 'c',
        default: 4,
        required: true,
    }), fetch: command_1.flags.boolean({
        char: 'f',
        description: 'Fetch from remote before checking status',
    }) });
exports.default = Status;
