"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const path = require("path");
const base_1 = require("../base");
class Unlink extends base_1.default {
    constructor() {
        super(...arguments);
        this.linkExists = (filepath) => {
            return fs.lstat(filepath)
                .then(st => {
                return fs.realpath(filepath)
                    .catch(_err => {
                    return st.isSymbolicLink();
                });
            })
                .catch(_err => {
                return false;
            });
        };
        this.getCustomSubdirPath = async () => {
            const userConfig = await this.getConfig();
            const coreRepo = path.resolve(path.join(userConfig.reposDir, this.flags['core-repo-name']));
            return path.resolve(path.join(coreRepo, 'Site', 'LmsSite', 'Custom'));
        };
    }
    async run() {
        await this.requireConfig();
        const customSubdir = await this.getCustomSubdirPath();
        const linkExists = await this.linkExists(customSubdir);
        if (linkExists) {
            return fs.unlink(customSubdir)
                .then(() => {
                return linkExists;
            })
                .catch(err => {
                console.error(err);
                return false;
            });
        }
        return false;
    }
}
Unlink.description = 'Unlink a custom dir to lms-core';
Unlink.flags = Object.assign({}, base_1.default.flags);
exports.default = Unlink;
