"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const Github = require("@octokit/rest");
const octokit = new Github({
    headers: {
        accept: 'application/vnd.github.symmetra-preview+json',
    },
});
function authenticate(params) {
    const { authToken, } = params;
    return new Promise((resolve, reject) => {
        if (!authToken) {
            return reject(new Error('Auth token is required.'));
        }
        octokit.authenticate({
            type: 'token',
            token: authToken,
        });
        return resolve();
    });
}
function getAuthenticatedOctokit(params) {
    return authenticate(params)
        .then(() => {
        return octokit;
    });
}
exports.getAuthenticatedOctokit = getAuthenticatedOctokit;
function getReposRaw(params) {
    const { repoQuery, } = params;
    return authenticate(params)
        .then(async () => {
        let response = await octokit.search.repos({
            q: repoQuery,
            per_page: 50,
        });
        let items = response.data.items;
        // @ts-ignore
        while (octokit.hasNextPage(response)) {
            // @ts-ignore
            response = await octokit.getNextPage(response);
            items = items.concat(response.data.items);
        }
        return items;
    });
}
exports.getReposRaw = getReposRaw;
function getRepos(options) {
    const { filter: repoFilterString, } = options;
    const lmsRepoRE = new RegExp(repoFilterString);
    return getReposRaw(options)
        .then((repos_raw) => {
        return repos_raw.map(repo => {
            return {
                name: repo.name,
                owner: repo.owner.login,
                repo: repo.name,
                full_name: repo.full_name,
                ssh_url: repo.ssh_url,
                git_url: repo.git_url,
                clone_url: repo.clone_url,
            };
        })
            .filter((repo) => {
            return lmsRepoRE.test(repo.name);
        });
    });
}
exports.getRepos = getRepos;
function editRepo(params) {
    const { 
    // tslint:disable-next-line
    authToken } = params, passedParams = tslib_1.__rest(params, ["authToken"]);
    return authenticate(params)
        .then(() => {
        return octokit.repos.edit(passedParams);
    });
}
exports.editRepo = editRepo;
function addRepoToTeam(params) {
    const { 
    // tslint:disable-next-line
    authToken } = params, passedParams = tslib_1.__rest(params, ["authToken"]);
    return authenticate(params)
        .then(async () => {
        //@ts-ignore - ignore missing deprecated `id` param
        return octokit.orgs.addTeamRepo(passedParams);
    });
}
exports.addRepoToTeam = addRepoToTeam;
function getTeams(params) {
    const { 
    // tslint:disable-next-line
    authToken } = params, passedParams = tslib_1.__rest(params, ["authToken"]);
    const serviceParams = Object.assign({ org: 'RoundtableLearning' }, passedParams);
    return authenticate(params)
        .then(async () => {
        //@ts-ignore - ignore missing deprecated `id` param
        return octokit.orgs.getTeams(serviceParams);
    })
        .then(response => response.data);
}
exports.getTeams = getTeams;
